<?php

class Widgets_Weather_Weather extends Widgets_Abstract
{
    /**
     * @const default day = 1 if options day not specified
     */
    const DEFAULT_DAY = '1';

    /**
     * Weather unit Celsius = metric
     */
    const UNITS_CELSIUS = 'metric';

    /**
     * Weather unit Kelvin = standard
     */
    const UNITS_KELVIN = 'standard';

    /**
     * Weather unit Fahrenheit = imperial
     */
    const UNITS_FAHRENHEIT = 'imperial';

    /**
     * Weather language
     */
    const WEATHER_LANG = 'en';

    /**
     * api query mode
     */
    const MODE_XML = 'xml';

    /**
     * Seotoaster config helper
     *
     * @var Helpers_Action_Config
     */
    protected $_configHelper = null;

    protected $_websiteHelper  = null;

    protected function _load()
    {
        if (empty($this->_options)) {
            throw new Exceptions_SeotoasterWidgetException('Not enough parameters');
        }
        $rendererName = '_render' . ucfirst(array_shift($this->_options));
        if (method_exists($this, $rendererName)) {
            return $this->$rendererName();
        }

        return '<!-- can not find renderer ' . $rendererName . ' -->';
    }

    protected function _init()
    {
        $this->_view = new Zend_View(array('scriptPath' => __DIR__ . '/views'));
        $this->_configHelper = Zend_Controller_Action_HelperBroker::getStaticHelper('config');
        $this->_websiteHelper = Zend_Controller_Action_HelperBroker::getStaticHelper('website');

        $this->_view->websiteUrl  = $this->_websiteHelper->getUrl();
    }

    /**
     * Widget params (data,(comma) time, (comma) clouds, (comma) wind, (comma) pressure, (comma) humidity, (comma) F).
     * For example {$weather:forecast:london,england:4:data,time,clouds,wind,pressure,humidity,F}
     *
     * @return string
     * @throws Exceptions_SeotoasterWidgetException
     **/
    protected function _renderForecast()
    {
        if (empty($this->_options[0])) {
            throw new Exceptions_SeotoasterWidgetException('Missed argument : city/country');
        }
        $appId = $this->_configHelper->getConfig('weatherApiKey');
        if (empty($appId)) {
            return $this->_translator->translate('Api key is missing');
        }

        $weatherForecast = new \cmfcmf\OpenWeatherMap();
        $days = self::DEFAULT_DAY;

        if (!empty($this->_options[1])) {
            $days = $this->_options[1];
            if(in_array('coords', $this->_options) && !empty($this->_options[2])) {
                $days = $this->_options[2];
            }
            if(!is_numeric($days)) {
                $days = self::DEFAULT_DAY;
            }
        }
        //pictures
        if(in_array('pic', $this->_options, true)){
            $this->_view->pictures = true;
        }

        if(in_array('C', $this->_options, true)){
            $unit = self::UNITS_CELSIUS;
        }else{
            $unit = self::UNITS_CELSIUS;
        }
        if(in_array('F', $this->_options, true)){
            $unit = self::UNITS_FAHRENHEIT;
        }
        if(in_array('K', $this->_options, true)){
            $unit = self::UNITS_KELVIN;
        }

        $query = $this->_options[0];
        if(in_array('coords', $this->_options)) {
            $coords = array_search('coords', $this->_options);
            $coords = explode(',', $this->_options[$coords+1]);

            if(is_array($coords) && (isset($coords[0]) && is_numeric($coords[0]) && isset($coords[1]) && is_numeric($coords[1]))) {
                $query = array('lat', 'lon');
                $query = array_combine($query, $coords);
            }
        }

        $forecastData = $weatherForecast->getRawDailyForecastData1($query, $unit, self::WEATHER_LANG,
            $appId, self::MODE_XML, $days);
        try {
            $weatherForecastData = new SimpleXMLElement($forecastData);
            if ('404' === $weatherForecastData->cod->__toString()) {
                return $this->_translator->translate('wrong city provided');
            }
        } catch (Exception $e) {
            return $this->_translator->translate('cant establish connection');
        }
        $locale = new Zend_Locale();
        $countries = $locale->getTranslationList('Territory', 'en', 2);

        $city = (string)$weatherForecastData->location[0]->name;
        $country = (string)$weatherForecastData->location->country;

        $optionsData = array(
            'data'     => 'data',
            'time'     => 'time',
            'clouds'   => 'forecastXmlClouds',
            'wind'     => 'forecastXmlWind',
            'pressure' => 'forecastXmlPressure',
            'humidity' => 'forecastXmlHumidity'
        );

        $paramOptions = (!empty($this->_options[2])) ? explode(',', trim($this->_options[2])) : array();
        $this->_view->forecastXml = $weatherForecastData;

        $this->_view->tempUnit = $unit;

        if (!empty($city)) {
            $this->_view->forecastXmlCity = $city;
        }

        if (!empty($country)) {
            if (!empty($countries[$country])) {
                $this->_view->forecastXmlCountry = $countries[$country];
            }
        }

        foreach ($optionsData as $key => $value) {
            if (in_array('all', $paramOptions, true)) {
                $this->_view->$value = true;
            } elseif (in_array($key, $paramOptions, true)) {
                $this->_view->$value = true;
            }
        }

        return $this->_view->render('forecast.weather.phtml');
    }
}

